 /**
   @version 1.01 2001-06-26
   @author Cay Horstmann
*/

import java.awt.*;
import java.awt.event.*;
import java.util.*;
import java.net.*;
import java.io.*;
import javax.swing.*;

/**
   Program demonstrujcy uycie gniazdek
   do wysyania wiadomoci poczty elektronicznej.
*/
public class MailTest
{  
   public static void main(String[] args)
   {  
      JFrame frame = new MailTestFrame();
      frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
      frame.show();
   }
}

/**
   Ramka interfejsu uytkownika.
*/
class MailTestFrame extends JFrame
{  
   public MailTestFrame()
   {  
      setSize(WIDTH, HEIGHT);
      setTitle("MailTest");

      getContentPane().setLayout(new GridBagLayout());

      GridBagConstraints gbc = new GridBagConstraints();
      gbc.fill = GridBagConstraints.HORIZONTAL;
      gbc.weightx = 0;
      gbc.weighty = 0;

      gbc.weightx = 0;
      add(new JLabel("From:"), gbc, 0, 0, 1, 1);
      gbc.weightx = 100;
      from = new JTextField(20);
      add(from, gbc, 1, 0, 1, 1);

      gbc.weightx = 0;
      add(new JLabel("To:"), gbc, 0, 1, 1, 1);
      gbc.weightx = 100;
      to = new JTextField(20);
      add(to, gbc, 1, 1, 1, 1);

      gbc.weightx = 0;
      add(new JLabel("SMTP server:"), gbc, 0, 2, 1, 1);
      gbc.weightx = 100;
      smtpServer = new JTextField(20);
      add(smtpServer, gbc, 1, 2, 1, 1);
 
      gbc.fill = GridBagConstraints.BOTH;
      gbc.weighty = 100;
      message = new JTextArea();
      add(new JScrollPane(message), gbc, 0, 3, 2, 1);

      communication = new JTextArea();
      add(new JScrollPane(communication), gbc, 0, 4, 2, 1);

      gbc.weighty = 0;
      JButton sendButton = new JButton("Send");
      sendButton.addActionListener(new
         ActionListener()
         {
            public void actionPerformed(ActionEvent evt)
            {  
               new 
                  Thread()
                  {
                     public void run()
                     {   
                        sendMail();
                     }
                  }.start();
            }            
         });
      JPanel buttonPanel = new JPanel();
      buttonPanel.add(sendButton);
      add(buttonPanel, gbc, 0, 5, 2, 1);
   }

   /**
      Umieszcza komponent w ramce.
      @param c umieszczany komponent
      @param gbc ograniczenia komponentu typu grid bag 
      @param x kolumna komponentu grid bag
      @param y wiersz komponentu grid bag
      @param w szerokos komponentu grid bag w kolumnach
      @param h wysoko komponentu grid bag w kolumnach
   */
   private void add(Component c, GridBagConstraints gbc,
      int x, int y, int w, int h)
   {  
      gbc.gridx = x;
      gbc.gridy = y;
      gbc.gridwidth = w;
      gbc.gridheight = h;
      getContentPane().add(c, gbc);
   }

   /**
      Wysya wiadomo poczty elektronicznej
      sformuowan z wykorzystaniem interfejsu uytkownika.
   */
   public void sendMail()
   {  
      try
      {  
         Socket s = new Socket(smtpServer.getText(), 25);

         out = new PrintWriter(s.getOutputStream());
         in = new BufferedReader(new
            InputStreamReader(s.getInputStream()));

         String hostName
            = InetAddress.getLocalHost().getHostName();

         receive();
         send("HELO " + hostName);
         receive();
         send("MAIL FROM: <" + from.getText() + ">");
         receive();
         send("RCPT TO: <" + to.getText() + ">");
         receive();
         send("DATA");
         receive();
         StringTokenizer tokenizer = new StringTokenizer(
            message.getText(), "\n");
         while (tokenizer.hasMoreTokens())
            send(tokenizer.nextToken());
         send(".");
         receive();
         s.close();
      }
      catch (IOException exception)
      {  
         communication.append("Error: " + exception);
      }
   }

   /**
      Wysya acuch znakw do gniazda 
      i pokazuje jego echo w polu tekstowym 
      monitorujcym przebieg komunikacji.
      @param s wysyany cig znakw.
   */
   public void send(String s) throws IOException
   {  
      communication.append(s);
      communication.append("\n");
      out.print(s);
      out.print("\r\n");
      out.flush();
   }

   /**
      Odbiera acuch znakw z gniazda
      i pokazuje go w polu tekstowym 
      monitorujcym przebieg komunikacji.
   */
   public void receive() throws IOException
   {
      String line = in.readLine();
      if (line != null)
      {
         communication.append(line);
         communication.append("\n");
      }
   }

   private BufferedReader in;
   private PrintWriter out;
   private JTextField from;
   private JTextField to;
   private JTextField smtpServer;
   private JTextArea message;
   private JTextArea communication;

   public static final int WIDTH = 300;
   public static final int HEIGHT = 300;  
}

