/**
   @version 1.11 2001-06-27
   @author Cay Horstmann
*/

import java.net.*;
import java.io.*;
import java.util.*;
import java.awt.*;
import java.awt.event.*;
import java.applet.*;
import javax.swing.*;

/**
   Applet wywietlajcy prognozy pogody z serwera NOAA
*/
public class WeatherApplet extends JApplet
{ 
   public void init()
   {  
      Container contentPane = getContentPane();
      contentPane.setLayout(new BorderLayout());

      // tworzy listy wyboru stanw i raportw
      JPanel comboPanel = new JPanel();
      state = makeCombo(states, comboPanel);
      report = makeCombo(reports, comboPanel);
      contentPane.add(comboPanel, BorderLayout.NORTH);

      // tworzy pole tekstowe
      weather = new JTextArea(20, 80);
      weather.setFont(new Font("Courier", Font.PLAIN, 12));

      // i przycisk pobierania raportu
      contentPane.add(new JScrollPane(weather), 
         BorderLayout.CENTER);
      JPanel buttonPanel = new JPanel();
      JButton reportButton = new JButton("Get report");
      reportButton.addActionListener(new
         ActionListener()
         {
            public void actionPerformed(ActionEvent evt)
            {  
               weather.setText("");
               new 
                  Thread()
                  {
                     public void run()
                     {
                        getWeather(getItem(state, states), 
                           getItem(report, reports));
                     }
                  }.start();
            }
         });

      buttonPanel.add(reportButton);
      contentPane.add(buttonPanel, BorderLayout.SOUTH);
   }

   /**
      Tworzy list rozwijaln.
      @param items tablica acuchw, ktrej pierwsza kolumna zawiera
      pozycje wywietlane na licie
      @param parent komponent nadrzdny listy
   */
   public JComboBox makeCombo(String[][] items, Container parent)
   {
      JComboBox combo = new JComboBox();
      for (int i = 0; i < items.length; i++)
         combo.addItem(items[i][0]);
      parent.add(combo);
      return combo;
   }
   
   /**
      Pobiera acuch zapytania odpowiadajcy pozycji wybranej na licie.
      @param box lista
      @param items tablica acuchw, ktrej pierwsza kolumna zawiera
      pozycje wywietlane na licie, a druga odpowiadajce im acuchy zapyta
      @return acuch zapytania
   */
   public String getItem(JComboBox box, String[][] items)
   {  
      return items[box.getSelectedIndex()][1];
   }

   /**
      Tworzy acuch zapytania URL i wypenia pole tekstowe
      uzyskanymi danymi.
      @param state cz zapytania dotyczca stanu
      @param report cz zapytania dotyczca raportu
   */
   public void getWeather(String state, String report)
   {  
      String r = new String();
      try
      {  
         String queryBase = getParameter("queryBase");
         String query
            = queryBase + state + "/" + report + ".html";
         URL url = new URL(query);
         BufferedReader in = new BufferedReader(new
            InputStreamReader(url.openStream()));

         String line;
         while ((line = in.readLine()) != null)
            weather.append(removeTags(line) + "\n");
      }
      catch(IOException e)
      {  
         showStatus("Error " + e);
      }
   }

   /**
      Usuwa etykiety HTML z acucha.
      @param s acuch
      @return s acuch z usunitymi etykietami <...>.
   */
   public static String removeTags(String s)
   {  
      while (true)
      {  
         int lb = s.indexOf('<');
         if (lb < 0) return s;
         int rb = s.indexOf('>', lb);
         if (rb < 0) return s;
         s = s.substring(0, lb) + " " + s.substring(rb + 1);
      }
   }

   private JTextArea weather;
   private JComboBox state;
   private JComboBox report;

   private String[][] states =
      {  
         { "Alabama", "al" },
         { "Alaska", "ak" },
         { "Arizona", "az" },
         { "Arkansas", "ar" },
         { "California", "ca" },
         { "Colorado", "co" },
         { "Connecticut", "ct" },
         { "Delaware", "de" },
         { "Florida", "fl" },
         { "Georgia", "ga" },
         { "Hawaii", "hi" },
         { "Idaho", "id" },
         { "Illinois", "il" },
         { "Indiana", "in" },
         { "Iowa", "ia" },
         { "Kansas", "ks" },
         { "Kentucky", "ky" },
         { "Lousisiana", "la" },
         { "Maine", "me" },
         { "Maryland", "md" },
         { "Massachusetts", "ma" },
         { "Michigan", "mi" },
         { "Minnesota", "mn" },
         { "Mississippi", "ms" },
         { "Missouri", "mo" },
         { "Montana", "mt" },
         { "Nebraska", "ne" },
         { "Nevada", "nv" },
         { "New Hampshire", "nh" },
         { "New Jersey", "nj" },
         { "New Mexico", "nm" },
         { "New York", "ny" },
         { "North Carolina", "nc" },
         { "North Dakota", "nd" },
         { "Ohio", "oh" },
         { "Oklahoma", "ok" },
         { "Oregon", "or" },
         { "Pennsylvania", "pa" },
         { "Rhode Island", "ri" },
         { "South Carolina", "sc" },
         { "South Dakota", "sd" },
         { "Tennessee", "tn" },
         { "Texas", "tx" },
         { "Utah", "ut" },
         { "Vermont", "vt" },
         { "Virginia", "va" },
         { "Washington", "wa" },
         { "West Virginia", "wv" },
         { "Wisconsin", "wi" },
         { "Wyoming", "wy" }
      };

   private String[][] reports =
      {  
         { "Hourly (State Weather Roundup)", "hourly" },
         { "State Forecast", "state" },
         { "Zone Forecast", "zone" },
         { "Short Term (NOWCASTS)", "shortterm" },
         { "Forecast Discussion", "discussion" },
         { "Weather Summary", "summary" },
         { "Public Information", "public" },
         { "Climate Data", "climate" },
         { "Hydrological Data", "hydro" },
         { "Watches", "watches" },
         { "Special Weather Statements", "special" },
         { "Warnings and Advisories", "allwarnings" }
      };
}



